pub struct ClrConstantPool {
pub strings: HashMap<String, u32>,
pub blobs: HashMap<Vec<u8>, u32>,
pub guids: HashMap<[u8; 16], u32>,
pub user_strings: HashMap<String, u32>,
}Expand description
CLR constant pool for storing various metadata.
Fields
strings: HashMap<String, u32>String pool (#Strings heap).
blobs: HashMap<Vec<u8>, u32>Binary large object pool (#Blob heap).
guids: HashMap<[u8; 16], u32>GUID pool (#GUID heap).
user_strings: HashMap<String, u32>User string pool (#US heap).
Implementations
Sourceimpl ClrConstantPool
impl ClrConstantPool
Sourcepub fn add_string(&mut self, s: String) -> u32
pub fn add_string(&mut self, s: String) -> u32
Adds a string to the string pool and returns its index.
Sourcepub fn add_blob(&mut self, b: Vec<u8>) -> u32
pub fn add_blob(&mut self, b: Vec<u8>) -> u32
Adds a binary blob to the blob pool and returns its index.
Sourcepub fn add_guid(&mut self, g: [u8; 16]) -> u32
pub fn add_guid(&mut self, g: [u8; 16]) -> u32
Adds a GUID to the GUID pool and returns its index.
Sourcepub fn add_user_string(&mut self, s: String) -> u32
pub fn add_user_string(&mut self, s: String) -> u32
Adds a user string to the user string pool and returns its index.