Module types

Module types 

CLR type definitions.

Structs

ClrAccessFlags
CLR access modifiers and flags
ClrAttribute
CLR attribute representing a custom attribute applied to a program element.
ClrExceptionHandler
CLR exception handler representing an exception handling clause in a method body.
ClrExternalAssembly
CLR external assembly reference representing a reference to an external .NET assembly.
ClrField
CLR field definition representing a field in a class or struct.
ClrLocalVariable
CLR local variable definition representing a local variable in a method body.
ClrMethodImplFlags
CLR method implementation flags
ClrModule
CLR module definition representing a module within an assembly.
ClrParameter
CLR method parameter definition representing a parameter in a method signature.
ClrVersion
CLR version information

Enums

ClrAttributeValue
CLR attribute value representing a value that can be passed to an attribute.
ClrExceptionHandlerType
CLR exception handler type indicating the kind of exception handling.
ClrReferenceType
CLR reference type indicating what kind of member is being referenced.
ClrTypeReference
CLR type reference representing a reference to a type in the CLR type system.