CLR program entity definitions.
Structs
- ClrMethod
- CLR method definition representing a method in a type.
- ClrProgram
- CLR assembly structure representing a complete .NET assembly.
- ClrType
- CLR type definition representing a class, struct, or interface.