CLR type definitions.
Structs
- ClrAccess
Flags - CLR access modifiers and flags
- ClrAttribute
- CLR attribute representing a custom attribute applied to a program element.
- ClrException
Handler - CLR exception handler representing an exception handling clause in a method body.
- ClrExternal
Assembly - CLR external assembly reference representing a reference to an external .NET assembly.
- ClrField
- CLR field definition representing a field in a class or struct.
- ClrLocal
Variable - CLR local variable definition representing a local variable in a method body.
- ClrMethod
Impl Flags - CLR method implementation flags
- ClrModule
- CLR module definition representing a module within an assembly.
- ClrParameter
- CLR method parameter definition representing a parameter in a method signature.
- ClrVersion
- CLR version information
Enums
- ClrAttribute
Value - CLR attribute value representing a value that can be passed to an attribute.
- ClrException
Handler Type - CLR exception handler type indicating the kind of exception handling.
- ClrReference
Type - CLR reference type indicating what kind of member is being referenced.
- ClrType
Reference - CLR type reference representing a reference to a type in the CLR type system.